--[[------------------------------------------]]--
--[[--LostTreasures_Config.lua				--]]--
--[[------------------------------------------]]--
local options = {
	type = "group", 
	name = _LT.NAME.." v".._LT.VERSION, 
	args = {
		configBox = {
			type = "group", 
			order = 100, 
			guiInline = true, 
			name = "Addon Config", 
			args = {
				enabledCheckbox = {
					type = "toggle", 
					order = 1, 
					name = "Enable Addon", 
					desc = "Toggles the addon on or off.", 
					get = function()
						return _LT.SavedVars.ENABLED
					end, 
					set = function(_, value)
						_LT.SavedVars.ENABLED = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
				debugCheckbox = {
					type = "toggle", 
					order = 2, 
					name = "Enable Debug", 
					desc = "Using debug will show debug messages and change the way waypoints are displayed.\n\nWill be removed once Blizzard fixes the quest flag.\n\nToggling this option will reset all waypoints.", 
					get = function()
						return _LT.SavedVars.DEBUG
					end, 
					set = function(_, value)
						_LT.SavedVars.DEBUG = value
						LostTreasures:DoWaypoints()
					end, 
				}, 
				hideMiningPickCheckbox = { -- Because Blizzfailed.org
					type = "toggle", 
					order = 3, 
					name = "Hide \"Ancient Pandaren Mining Pick\" Waypoint", 
					desc = "This will allow you to hide the \"Ancient Pandaren Mining Pick\" from your waypoints.\n\nWill be removed once Blizzard fixes the quest flag.", 
					get = function()
						return _LT.SavedVars.BLOCK_MINING_PICK
					end, 
					set = function(_, value)
						_LT.SavedVars.BLOCK_MINING_PICK = value
						if ( _LT.SavedVars.BLOCK_MINING_PICK ) then
							LostTreasures:DoWaypoints({removeAll = false, addAll = false, removePoint = 31399})
						else
							LostTreasures:DoWaypoints({removeAll = false, addAll = false, addPoint = 31399})
						end
					end, 
				}, 
				navigationBox = {
					type = "group", 
					order = 4, 
					guiInline = true, 
					name = "TomTom Options", 
					args = {
						miniMapCheckbox = {
							type = "toggle", 
							order = 1, 
							name = "Enable Minimap Waypoints", 
							desc = "Using this will show lost treasure waypoints on the minimap.\n\nToggling this option will reset all waypoints.", 
							width = "double", 
							get = function()
								return _LT.SavedVars.USE_MINIMAP
							end, 
							set = function(_, value)
								_LT.SavedVars.USE_MINIMAP = value
								LostTreasures:DoWaypoints()
							end, 
						}, 
						worldMapCheckbox = {
							type = "toggle", 
							order = 2, 
							name = "Enable World Map Waypoints", 
							desc = "Using this will show lost treasure waypoints on the world map.\n\nToggling this option will reset all waypoints.", 
							width = "double", 
							get = function()
								return _LT.SavedVars.USE_WORLDMAP
							end, 
							set = function(_, value)
								_LT.SavedVars.USE_WORLDMAP = value
								LostTreasures:DoWaypoints()
							end, 
						}, 
						arrowBox = {
							type = "group", 
							order = 3, 
							guiInline = true, 
							name = "Arrow Options", 
							args = {
								arrowCheckbox = {
									type = "toggle", 
									order = 1, 
									name = "Enable TomTom Arrow", 
									desc = "Using this will have the TomTom arrow point to the closest lost treasure waypoint.", 
									width = "double", 
									get = function()
										return _LT.SavedVars.USE_ARROW
									end, 
									set = function(_, value)
										_LT.SavedVars.USE_ARROW = value
										LostTreasures:DoWaypoints({removeAll = false, addAll = false})
									end, 
								}, 
								treasuresFirstCheckbox = {
									type = "toggle", 
									order = 2, 
									name = "Point to Hidden Treasures First", 
									desc = "Using this will have the TomTom arrow point to lost treasure waypoints (while they exist on the map) before quest and other waypoints. It will also print detailed information about the waypoint to your chat box.\nThis can be useful when hunting treasures.\n\nSimply disable this to have the arrow go back to normal.", 
									width = "double", 
									get = function()
										return _LT.SavedVars.TREASURE_FIRST
									end, 
									set = function(_, value)
										_LT.SavedVars.TREASURE_FIRST = value
										LostTreasures:DoWaypoints({removeAll = false, addAll = false})
									end, 
								}, 
								outsideZoneCheckbox = {
									type = "toggle", 
									order = 3, 
									name = "Allow closest waypoint to be outside current zone", 
									desc = "This will allow the TomTom arrow to point to waypoints outside of your current zone.\nThis can be useful when hunting treasures.\n\nPlease note that this will change the default setting for TomTom!\n\nYou can change this setting back here or in TomTom's options menu.\n\nGame Options (Esc) > Interface > AddOns > TomTom > Waypoint Arrow > Allow closest waypoint to be outside current zone", 
									width = "double", 
									get = function()
										return TomTom.profile.arrow.closestusecontinent
									end, 
									set = function(_, value)
										TomTom.profile.arrow.closestusecontinent = value
										LostTreasures:DoWaypoints({removeAll = false, addAll = false})
									end, 
								}, 
							}, 
						}, 
						clearDistanceSlider = {
							type = "range", 
							order = 4, 
							name = "Waypoint Clear Distance", 
							desc = "This will allow you to change how close you have to get to a lost treasure waypoint in order for it to be removed.\n\nOff - 0\nDefault - 3\nMax - 10\n\nYou must reload your UI in order for this to take effect.", 
							width = "double", 
							min = 1, max = 10, step = 1, 
							get = function()
								return _LT.SavedVars.CLEARDISTANCE
							end, 
							set = function(_, value)
								_LT.SavedVars.CLEARDISTANCE = value
							end, 
						}, 
					}, 
				}, 
				reloadWaypointsButton = {
					type = "execute", 
					order = 5, 
					name = "Reload Waypoints", 
					desc = "Reload all waypoints so you can begin a new trip.\n\nCommand to reload waypoints\n/lt reload", 
					func = function()
						LostTreasures:DoWaypoints({removeAll = true, addAll = true, setArrow = true, addPoint = 0, removePoint = 0})
					end, 
				}, 
				reloadUIButton = {
					type = "execute", 
					order = 6, 
					name = "Reload UI", 
					desc = "Reloads the Blizzard UI.", 
					func = function()
						ReloadUI()
					end, 
				}, 
			}, 
		}, 
	}, 
}
AceConfigRegistry:RegisterOptionsTable("LostTreasures", options)
AceConfigDialog:AddToBlizOptions("LostTreasures", _LT.NAME)